@@ -2,15 +2,15 @@
 import os
 import sys
 import threading
-from os import path, environ
 from getopt import getopt
+from os import path, environ
 
 from oss2 import Auth
 
 from lang.io import Properties
 
 __title__ = 'py-cli'
-__version__ = '1.2.1'
+__version__ = '1.2.2'
 
 __PYCLI_PATH = path.abspath(path.join(path.dirname(os.getcwd()), '.'))
 __LIBS_PATH = path.join(__PYCLI_PATH, 'libs')
@@ -25,14 +25,27 @@ class ArgOpts(object):
 
     project_path = ''
     app_module = ''
+
     output_path = ''
+    channel_config_path = ''
 
     def __init__(self):
         self.operate = sys.argv[1]
+        if self.operate in ("-v", "--version"):
+            print(__version__)
+            sys.exit(0)
 
+        elif self.operate in ("-h", "--help"):
+            print_usage()
+            sys.exit(0)
+
+        else:
+            self.parse_args()
+
+    def parse_args(self):
         opts, args = getopt(sys.argv[2:],
-                            'hp:m:c:o:v',
-                            ['help', 'project=' 'module=', 'channel=', 'output=', 'version'])
+                            'p:m:c:o:',
+                            ['project=' 'module=', 'channel=', 'output='])
         if opts:
             for opt, arg in opts:
                 if opt in ("-p", "--project"):
@@ -46,15 +59,10 @@ class ArgOpts(object):
                         raise RuntimeError('[ERROR]: Usage: pycli -m <your project path> | --project="your project path"')
 
                 elif opt in ("-c", "--channel"):
-                    self.safety_flag = True
+                    self.channel_config_path = arg
 
-                elif opt in ("-v", "--version"):
-                    print(__version__)
-                    sys.exit(0)
-
-                elif opt in ("-h", "--help"):
-                    print_usage()
-                    sys.exit(0)
+                elif opt in ("-o", "--output"):
+                    self.output_path = arg
 
         if len(self.project_path) <= 0:
             cwd_path = os.getcwd()
@@ -63,9 +71,13 @@ class ArgOpts(object):
 
             else:
                 raise RuntimeError('\n[ERROR]: 当前目录非Android工程目录，请指定编译目录！！！')
+
         if not self.app_module:
             self.app_module = 'app'
 
+        if not self.output_path:
+            self.output_path = os.getcwd()
+
 
 class PyCliConfig(object):
     """
